@@ -10,16 +10,19 @@ if(class(xc) == "mefa") {
 ifelse(which == "samples", table <- xc$xcount, table <- t(xc$xcount))
 ifelse(which == "samples", str <- as.factor(xc$sample.attr[,strata]), 
 str <- as.factor(xc$species.attr[,strata]))}
+
+if(nrow(table) == 1) {
+	ifelse(which =="samples", stop("One sample can not be stratified."), stop("One species can not be stratified."))}
+if(nlevels(str) == 1) stop("More than only one strata is needed.")
+
 table.out <- array(data=NA, dim=c(nlevels(str), dim(table)[2]))
 for(i in 1:dim(table.out)[2]){table.out[,i] <- aggregate(table[,i], list(str), sum)[[2]]}
 colnames(table.out) <- colnames(table)
 rownames(table.out) <- levels(str)
 ifelse(which == "samples", data <- as.matrix(table.out), data <- as.matrix(t(table.out)))
 data <- data[order(as.character(rownames(data))), order(as.character(colnames(data)))]
-out <- list(segment = xc$segment,
-data = data,
-nsamples = dim(data)[1],
-nspecies = dim(data)[2])
-class(out) <- "xcount"
+
+out <- as.xcount(data, segment=xc$segment)
+
 return(out)}
 
